==> surf_logger-0.0.1-dev.6.tar.gz: lib/src/logger.dart <==
// Copyright (c) 2019-present,  SurfStudio LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import 'package:surf_logger/src/const.dart';
import 'package:surf_logger/src/strategies/log_strategy.dart';

/// Wrapping for logging using various strategies
class Logger {
  static final _strategies = <Type, LogStrategy>{};

  ///debug
  static void d(String msg, [Exception error]) {
    _forAllStrategies(
      (strategy) => strategy.log(msg, priorityLogDebug, error),
    );
  }

  ///warn (for expected errors)
  static void w(String msg, [Exception error]) {
    _forAllStrategies(
      (strategy) => strategy.log(msg, priorityLogWarn, error),
    );
  }

  ///error (for errors)
  static void e(String msg, [Exception error]) {
    _forAllStrategies(
      (strategy) => strategy.log(msg, priorityLogError, error),
    );
  }

  static void addStrategy(LogStrategy strategy) {
    _strategies[strategy.runtimeType] = strategy;
  }

  static void removeStrategy(LogStrategy strategy) {
    _strategies.remove(strategy.runtimeType);
  }

  static void _forAllStrategies(Function(LogStrategy strategy) action) {
    _strategies.values.forEach(action);
  }
}

==> surf_logger-1.0.0-dev.1.tar.gz: lib/src/logger.dart <==
// Copyright (c) 2019-present,  SurfStudio LLC
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

import 'package:surf_logger/src/const.dart';
import 'package:surf_logger/src/strategies/log_strategy.dart';

/// Wrapping for logging using various strategies
class Logger {
  static final _strategies = <Type, LogStrategy>{};

  /// debug
  static void d(String msg, [Exception? error]) {
    _forAllStrategies(
      (strategy) => strategy.log(msg, priorityLogDebug, error),
    );
  }

  /// warn (for expected errors)
  static void w(String msg, [Exception? error]) {
    _forAllStrategies(
      (strategy) => strategy.log(msg, priorityLogWarn, error),
    );
  }

  /// error (for errors)
  static void e(String msg, [Exception? error]) {
    _forAllStrategies(
      (strategy) => strategy.log(msg, priorityLogError, error),
    );
  }

  static void addStrategy(LogStrategy strategy) {
    _strategies[strategy.runtimeType] = strategy;
  }

  static void removeStrategy(LogStrategy strategy) {
    _strategies.remove(strategy.runtimeType);
  }

  static void _forAllStrategies(Function(LogStrategy) action) {
    _strategies.values.forEach(action);
  }
}
